@@ -151,8 +151,8 @@ class WorkerServer(BaseServer):
         # Shut things down
         LOGGER.info('Closing broker connection')
         yield self.chan.channel_close()
-        # chan0 = yield self.conn.channel(0)
-        # yield chan0.connection_close()
+        chan0 = yield self.conn.channel(0)
+        yield chan0.connection_close()
         #TODO close mysql connection
         #TODO close memcache connection
         
